@@ -18,3 +18,9 @@ class AlbumList(generic.list.ListView):
 class PictureDetail(generic.detail.DetailView):
     model = Picture
     queryset = Picture.objects.public()
+
+
+class PictureList(generic.list.ListView):
+    model = Picture
+    queryset = Picture.objects.public()
+    paginate_by = 16
